@@ -120,6 +120,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub struct Config {
                 pub google_application_credentials: String,
                 pub payment_processing_topic: String,
+                pub order_events_topic: String,
                 pub bind_address: String,
             }
 
@@ -127,6 +128,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 Config {
                     google_application_credentials: env::var("GOOGLE_APPLICATION_CREDENTIALS").unwrap(),
                     payment_processing_topic: env::var("PAYMENT_PROCESSING_TOPIC").unwrap(),
+                    order_events_topic: env::var("ORDER_EVENTS_TOPIC").unwrap(),
                     bind_address: env::var("BIND_ADDRESS").unwrap(),
                 }
             }
@@ -695,7 +697,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
                 let api = Self::api_description();
                 let config = checkout_server::get_config();
-                let internal_context = checkout_server::InternalContext::new(config.google_application_credentials.clone(), config.payment_processing_topic.clone()).await?;
+                let internal_context = checkout_server::InternalContext::new(config.google_application_credentials.clone(), config.payment_processing_topic.clone(), config.order_events_topic.clone()).await?;
                 let context_provider = checkout_server::Arc::new(self);
 
                 let pubsub_client = internal_context.pubsub_client.clone();
